==> central-repository-3.62.0.zip: com/microej/pack/vg/vg-pack/1.2.1/CHANGELOG-1.2.1.md <==
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.2.1] - 2023-02-06

### Fixed

- [Front Panel] Fix the cropped images when using GraphicsContext clip and translation.
- [Front Panel] Fix AWT `RasterFormatException` exception.

## [1.2.0] - 2022-12-30

### Added

- Add "fill alpha" and "stroke alpha" animations to gradient elements.

### Changed

- Implement MicroVG 1.2.0.
- Change the VectorImage internal format: _raw_ format instead of _immutables_ format.

### Fixed

- [Front Panel] Fix the redirection of fillEllipseArc to the right software alogorithm.

## [1.1.2] - 2022-10-14

### Changed

- Update Vector Image Generator to version 1.0.3 for faster conversion.

## [1.1.1] - 2022-09-05

### Fixed

- Fix the README.md file for publication.

## [1.1.0] - 2022-09-02

### Added

- Add a sanity check on UI Pack fetched by the platform and the minimal version expected by the VG pack.
- Add the VG Pack version in the header file LLVG_impl.h.

### Changed

- Implement MicroVG 1.1.0 (can close a VectorFont, Matrix.getSNIContext()). 
- Allow to load a VectorFont from the external resources. 
- Add layout modes (simple or complex) feature to VectorFont(see limitations in README.md).
- Join character bboxes at baseline for drawStringOnCircle.

### Fixed

- Fix NullPointerException while sorting TranslateXY VectorDrawableObjectAnimator in vectorimage-converter.

## [1.0.1] - 2022-05-16

### Fixed

- Fix incorrect transformation of animated paths while creating a filteredImage.
- Fix incorrect detection of overlapping paths in vector images.

## [1.0.0] - 2022-05-13

### Added

- Initial revision.
- Implement MicroVG-1.0.0

---
_Copyright 2022-2023 MicroEJ Corp. All rights reserved._  
_This library is provided in source code for use, modification and test, subject to license terms._  
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._

==> central-repository-3.63.0.zip: com/microej/pack/vg/vg-pack/1.3.0/CHANGELOG-1.3.0.md <==
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.3.0] - 2023-05-10

### Changed

- Implement MicroVG 1.3.0.
- [Front Panel] Change the implementation to be compatible with the UI Pack 13.5.0.

### Fixed

- [Front Panel] Simplify pixels data conversion after drawing.
- [Image Generator] Support SVG clip-path feature.

## [1.2.1] - 2023-02-06

### Fixed

- [Front Panel] Fix the cropped images when using GraphicsContext clip and translation.
- [Front Panel] Fix AWT `RasterFormatException` exception.

## [1.2.0] - 2022-12-30

### Added

- Add "fill alpha" and "stroke alpha" animations to gradient elements.

### Changed

- Implement MicroVG 1.2.0.
- Change the VectorImage internal format: _raw_ format instead of _immutables_ format.

### Fixed

- [Front Panel] Fix the redirection of fillEllipseArc to the right software alogorithm.

## [1.1.2] - 2022-10-14

### Changed

- Update Vector Image Generator to version 1.0.3 for faster conversion.

## [1.1.1] - 2022-09-05

### Fixed

- Fix the README.md file for publication.

## [1.1.0] - 2022-09-02

### Added

- Add a sanity check on UI Pack fetched by the platform and the minimal version expected by the VG pack.
- Add the VG Pack version in the header file LLVG_impl.h.

### Changed

- Implement MicroVG 1.1.0 (can close a VectorFont, Matrix.getSNIContext()). 
- Allow to load a VectorFont from the external resources. 
- Add layout modes (simple or complex) feature to VectorFont(see limitations in README.md).
- Join character bboxes at baseline for drawStringOnCircle.

### Fixed

- Fix NullPointerException while sorting TranslateXY VectorDrawableObjectAnimator in vectorimage-converter.

## [1.0.1] - 2022-05-16

### Fixed

- Fix incorrect transformation of animated paths while creating a filteredImage.
- Fix incorrect detection of overlapping paths in vector images.

## [1.0.0] - 2022-05-13

### Added

- Initial revision.
- Implement MicroVG-1.0.0

---
_Copyright 2022-2023 MicroEJ Corp. All rights reserved._  
_This library is provided in source code for use, modification and test, subject to license terms._  
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._
